plot.bglasso_out: plot the graph estimated by graphical lasso with threshold...

Description Usage Arguments Value

View source: R/utils.R

Description

plot the graph estimated by graphical lasso with threshold method using ggraph

Usage

1
2
## S3 method for class 'bglasso_out'
plot(x, ...)

Arguments

x

The bglasso_out

...
  • tol: threshold for ploting default 0.01, if horseshoed, then horseshoe result is used

Value

A ggplot xect


CARlasso documentation built on Aug. 12, 2021, 1:05 a.m.